//------------------------------------------------------------------------
// File name...............: PrintReport.cpp
// Library.................: Microsoft Foundation Classes
// Beskrivelse.............:				   
//		Headerdefinition af egne Report-klasser
//
//------------------------------------------------------------------------
#include "PrintReport.h"

CxReportHandler ReportHandler;			// global Report-handler

//------------------------------------------------------------------------
//	Basis Report-interface
//------------------------------------------------------------------------
CxReport::CxReport	(void)
: MaxLinesPerPage (0)
, LinesPerPage (0)
, ReportName ("")
{}

CxReport::CxReport	(CString MyReportName, long MyMaxLinesPerPage)
: MaxLinesPerPage (MyMaxLinesPerPage)
, LinesPerPage (MyMaxLinesPerPage)
, ReportName (MyReportName)
{}

CxReport::~CxReport	(void)
{}

void	CxReport::DeleteReport(void)
{ delete this; }

void	CxReport::SetReportID(long	NyID)
{ ReportID = NyID; }

long	CxReport::GetReportID(void)
{ return (ReportID); }

CString	CxReport::GetReportName(void)
{ return (ReportName); }

long	CxReport::GetMaxLinesPerPage(void)
{ return (MaxLinesPerPage); }

void	CxReport::SetLinesPerPage(long NewLinesPerPage)
{ LinesPerPage = NewLinesPerPage; }

void	CxReport::BeginOfPrintReport(void)
{}
void	CxReport::BeginOfViewReport(void)
{ BeginOfPrintReport(); }

CString	CxReport::GetLine(void)
{ return (""); }

BOOL	CxReport::EndOfReport(void)
{ return (TRUE); }

//------------------------------------------------------------------------
//	ReportHandler klasse   -   styrer print sammen med klasserne
//								CWindowsDoc og CWindowsView 
//------------------------------------------------------------------------

CxReportHandler::CxReportHandler	(void)
:	MaxReport(-1), AktReport(0), LastReportID(0)
{}

CxReportHandler::~CxReportHandler	(void)
{ 
	for (int i=0; i <= MaxReport; ++i)
	{
		pReport[i]->DeleteReport();
		pReport[i] = NULL;
	}
}

void	CxReportHandler::AddReport(CxReport* pNewReport)
{ 
	assert (MaxReport < 20);
	pNewReport->SetReportID(++LastReportID);
	pReport[++MaxReport] = pNewReport;
}

void	CxReportHandler::RemoveReport(CxReport* pValgReport)
{
	assert (pValgReport != NULL);
	for (int i=0; (i < MaxReport)&&(pReport[i]!=pValgReport); ++i);
	if (pReport[i]=pValgReport)
	{
		pReport[i]->DeleteReport();
		--MaxReport;
		for (; (i < MaxReport); ++i);
			pReport[i] = pReport[i+1];
	}
}

CxReport*	CxReportHandler::GetFirstReport(void)
{ 
	AktReport=0;
	if (AktReport <= MaxReport)
		return (pReport[AktReport]);
	else
		return (NULL);
}

CxReport*	CxReportHandler::GetNextReport(void)
{ 
	if (AktReport < MaxReport)
		return (pReport[++AktReport]);
	else
		return (NULL);
}

//-----------------------------------------------------------
//  Printer objekt
//-----------------------------------------------------------

CxPrint::CxPrint(void)
: PrintLineNr(0), PrintIsOpen(FALSE), PrintIsClosed(TRUE)
{}

CxPrint::~CxPrint(void)
{}

void	CxPrint::DeleteReport(void)
{
	TextLines.RemoveAll();
	delete this;
}

void	CxPrint::OpenPrint(CString MyPrintJobName, long MyMaxLinesPerPage)
{
	assert (!PrintIsOpen);
	PrintIsClosed = FALSE;
	PrintIsOpen	= TRUE;
	TextLines.RemoveAll();
	ReportName = MyPrintJobName;
	MaxLinesPerPage = MyMaxLinesPerPage;
}
void	CxPrint::ClosePrint(void)
{
	assert (PrintIsOpen);
	PrintIsClosed = TRUE;
}

void	CxPrint::PrintLine(CString TextLine)
{ 
	assert (PrintIsOpen);
	TextLines.Add(TextLine);
}

void	CxPrint::BeginOfPrintReport(void)
{
	assert (PrintIsClosed);
	PrintLineNr = 0;
}

CString	CxPrint::GetLine(void)
{ 
	assert (PrintIsClosed);
	return (TextLines[PrintLineNr++]);
}

BOOL	CxPrint::EndOfReport(void)
{ 
	assert (PrintIsClosed);
	return (PrintLineNr >= TextLines.GetSize());
}


