//------------------------------------------------------------------------
// File name...............: ReportMetrics.cpp
// Library.................: Microsoft Foundation Classes
// Beskrivelse.............:				   
//		Headerdefinition af CxReportMetrics-klasse
//
//		Denne klasse anvendes ved dokomentbehandling til styring
//		af print og skrm sider
//
//------------------------------------------------------------------------
#include "ReportMetrics.h"

void CxReportMetrics::ComputeReportMetrics(CDC *pDC, CWnd *pWnd, long MaxLinesPerPage) 
{
	CFont	Courier;

	int Height = -pDC->GetDeviceCaps(LOGPIXELSY); //(VERTRES)
	SHeight = Height;

    if (pDC->IsPrinting())
	{
		if (MaxLinesPerPage > 64) 
			Height = 2850/MaxLinesPerPage;
		else
			Height = 1980/MaxLinesPerPage;
	}
    else
		Height = 16;

	Courier.CreateFont (Height,0,0,0,FW_NORMAL, 0,0,0,
		 DEFAULT_CHARSET, OUT_CHARACTER_PRECIS, CLIP_CHARACTER_PRECIS,
		 DEFAULT_QUALITY, DEFAULT_PITCH | FF_DONTCARE, "Courier New");

//    if (!pDC->IsPrinting())
//		pWnd->SetFont(&Courier);	
//    else

	pDC->SelectObject(&Courier);	


    TEXTMETRIC tm;

    CRect rectClient;

    int nPageHeight;

    if (!pDC->IsPrinting())
            pDC->SetMapMode(MM_TEXT); 
    else
            pDC->SetMapMode(MM_LOMETRIC); 

    if (!pDC->GetTextMetrics(&tm))
    {
            AfxMessageBox("TextMetrics er ikke tilgngelige!",MB_OK | MB_ICONSTOP);
            return;
    }

    m_nMinCharWidth = tm.tmAveCharWidth;
    m_nAvgCharWidth = (tm.tmAveCharWidth + tm.tmMaxCharWidth) / 2;
    m_nMaxCharWidth = tm.tmMaxCharWidth; 

    m_nLineHeight = tm.tmHeight + tm.tmExternalLeading;
    m_nLineWidth = m_nAvgCharWidth * 76; 

    if (!pDC->IsPrinting())
    {
            pWnd->GetClientRect(&rectClient); // Vindue strrelse
            pDC->DPtoLP(&rectClient); // Konverter til logisk
            rectClient.NormalizeRect(); // Normaliser
            nPageHeight = rectClient.Height();// Side hjde (logisk)
    }
    else
    {
            int nHRes = pDC->GetDeviceCaps(HORZRES);// Print x-pix
            int nVRes = pDC->GetDeviceCaps(VERTRES);// Print y-pix
            rectClient.SetRect(0, 0, nHRes, nVRes); // Print side
            pDC->DPtoLP(&rectClient); // Konverter til logisk
            rectClient.NormalizeRect(); // Normaliser
            nPageHeight = rectClient.Height();// Side hjde (logisk)
    }

    // Beregn helt antal linier pr side
	m_nLinesPerPage = nPageHeight / m_nLineHeight;

//    if (pDC->IsPrinting())
//		m_nLinesPerPage = m_nLinesPerPage - 3; // Plads til topmargin

    if (m_nLinesPerPage > MaxLinesPerPage)
		m_nLinesPerPage = MaxLinesPerPage;
		


    // Beregn pixels pr side til helt antal linier
    nPageHeight = m_nLinesPerPage * m_nLineHeight; 

    // Horizontal side scroll 1/5 linie
    m_PageSize.cx = m_nLineWidth / 5;

    // Vertikal side scroll
    m_PageSize.cy = max(m_nLineHeight, nPageHeight);

    // Horizontal linie scroll 1/20 linie
    m_LineSize.cx = m_nLineWidth / 20; 

    // Vertikal linie scroll
    m_LineSize.cy = m_nLineHeight;
}